CHANGELOG
=========

0.3 2018-10-13
--------------

 * Fix python packaging

0.2 2018-10-13
--------------

 * Add security restriction based on permission prometheus:metrics:read
 * Add a setting to obfuscate the /metrics url

0.1 2018-10-10
--------------

 * Initial release with a /metrics route that expose prometheus metrics
